@@ -2,7 +2,7 @@
 
 from django.contrib import admin
 
-from .models import Account, Transaction
+from .models import Account, BalanceClaim, Transaction
 
 
 class AccountAdmin(admin.ModelAdmin):
@@ -20,6 +20,19 @@ class AccountAdmin(admin.ModelAdmin):
 admin.site.register(Account, AccountAdmin)
 
 
+class BalanceClaimAdmin(admin.ModelAdmin):
+    list_display = (
+        'account',
+        'amount',
+        'is_released',
+        'comment',
+        'created',
+        'modified',
+    )
+
+admin.site.register(BalanceClaim, BalanceClaimAdmin)
+
+
 class TransactionAdmin(admin.ModelAdmin):
     list_display = (
         'source_account',
